@@ -38,6 +38,7 @@ impl SocketForwarder {
     }
 
     pub async fn run(mut self) {
+        #[cfg(feature = "tracing")]
         tracing::debug!("starting driving loop");
 
         loop {
@@ -53,14 +54,19 @@ impl SocketForwarder {
                 // `rx` future finished first.
                 Either::Left((Either::Left((maybe_msg, _)), _)) => {
                     if let Some(msg) = maybe_msg {
+                        #[cfg(feature = "tracing")]
                         tracing::trace!("sending message: {}", msg);
 
-                        if let Err(err) = self.stream.send(msg).await {
-                            tracing::warn!("sending failed: {}", err);
+                        if let Err(_source) = self.stream.send(msg).await {
+                            #[cfg(feature = "tracing")]
+                            tracing::warn!("sending failed: {}", _source);
+
                             break;
                         }
                     } else {
+                        #[cfg(feature = "tracing")]
                         tracing::debug!("rx stream ended, closing socket");
+
                         let _res = self.stream.close(None).await;
 
                         break;
@@ -73,23 +79,30 @@ impl SocketForwarder {
                             break;
                         }
                     }
-                    Some(Err(err)) => {
-                        tracing::warn!("socket errored: {}", err);
+                    Some(Err(_source)) => {
+                        #[cfg(feature = "tracing")]
+                        tracing::warn!("socket errored: {}", _source);
+
                         break;
                     }
                     None => {
+                        #[cfg(feature = "tracing")]
                         tracing::debug!("socket ended");
+
                         break;
                     }
                 },
                 // Timeout future finished first.
                 Either::Right((_, _)) => {
+                    #[cfg(feature = "tracing")]
                     tracing::warn!("socket timed out");
+
                     break;
                 }
             };
         }
 
+        #[cfg(feature = "tracing")]
         tracing::debug!("Leaving loop");
     }
 }
